@@ -198,30 +198,30 @@ class Gen(BaseGen):
             non-sequential or do not start from 0, so a 'gid' column is added.
         """
         if self._meta is None:
-            if not self._multi_h5_res:
-                res_cls = Resource
-                kwargs = {'hsds': self._hsds}
-            else:
+            res_cls = Resource
+            kwargs = {'hsds': self._hsds}
+            if self._multi_h5_res:
                 res_cls = MultiFileResource
                 kwargs = {}
 
-            with res_cls(self.res_file, **kwargs) as res:
-                res_meta = res.meta
-
             res_gids = self.project_points.sites
             if self._gid_map is not None:
                 res_gids = [self._gid_map[i] for i in res_gids]
 
-            if np.max(res_gids) > len(res_meta):
-                msg = ('ProjectPoints has a max site gid of {} which is '
-                       'out of bounds for the meta data of size {} from '
-                       'resource file: {}'
-                       .format(np.max(res_gids),
-                               res_meta.shape, self.res_file))
-                logger.error(msg)
-                raise ProjectPointsValueError(msg)
+            with res_cls(self.res_file, **kwargs) as res:
+                meta_len = res.shapes['meta'][0]
+
+                if np.max(res_gids) > meta_len:
+                    msg = ('ProjectPoints has a max site gid of {} which is '
+                           'out of bounds for the meta data of len {} from '
+                           'resource file: {}'
+                           .format(np.max(res_gids),
+                                   meta_len, self.res_file))
+                    logger.error(msg)
+                    raise ProjectPointsValueError(msg)
+
+                self._meta = res['meta', res_gids]
 
-            self._meta = res_meta.iloc[res_gids, :]
             self._meta.loc[:, 'gid'] = res_gids
             self._meta.index = self.project_points.sites
             self._meta.index.name = 'gid'
@@ -545,10 +545,11 @@ class Gen(BaseGen):
         try:
             if max_workers == 1:
                 logger.debug('Running serial generation for: {}'.format(pc))
-                for pc_sub in pc:
+                for i, pc_sub in enumerate(pc):
                     gen.out = gen.run(pc_sub, **kwargs)
-                    logger.info('Finished reV gen serial compute for: {}'
-                                .format(pc_sub))
+                    logger.info('Finished reV gen serial compute for: {} '
+                                '(iteration {} out of {})'
+                                .format(pc_sub, i + 1, len(pc)))
                 gen.flush()
             else:
                 logger.debug('Running parallel generation for: {}'.format(pc))
