@@ -690,6 +690,9 @@ def launch_slurm(config, verbose):
     stdout_path = os.path.join(config.logdir, 'stdout/')
     node_cmd = get_multiple_cmds(config, out_dir, log_file, verbose)
 
+    if config.execution_control.sh_script:
+        node_cmd = config.execution_control.sh_script + '\n' + cmd
+
     slurm_manager = SLURM()
     status = Status.retrieve_job_status(out_dir, 'qa-qc', config.name,
                                         hardware='eagle',
